@@ -113,7 +113,7 @@ split_replace <- function(raster, partPerSide, h, v, outputPath, name, save = TR
     }
   }
   
-  agg <- getAggregate(raster, h = h, v = v)
+  agg <- getAggregate(raster=raster, h = h, v = v)
   
   agg[] <- 1:ncell(agg)
   
@@ -143,26 +143,26 @@ split_replace <- function(raster, partPerSide, h, v, outputPath, name, save = TR
                                   polygon_extent = extent_polygon)
       
       for(k in 1:nlayers(raster)){
-        temp_r <- addLayer(temp_r, output[[k]])
+        temp_r <- addLayer(x=temp_r, output[[k]])
       }
       
     } else {
       for(k in 1:nlayers(raster)){
-        aux_r <- crop(raster[[k]], extent_polygon)
-        temp_r <- addLayer(temp_r, aux_r)
+        aux_r <- raster::crop(x=raster[[k]], y=extent_polygon)
+        temp_r <- addLayer(x=temp_r, aux_r)
       }
     }
     
-    if(replace == TRUE){
-      temp_r <- reclassify( temp_r, cbind( valToReplace, replacedBy ) )
+    if(replace){
+      temp_r <- reclassify( x=temp_r, rcl=cbind( valToReplace, replacedBy ) )
     }
     
-    if(save == TRUE){
-      writeRaster(temp_r, filename = paste0(outputPath, "/", name, "_", i),
-                  format = format, datatype = dataType, overwrite = TRUE, ...)  
+    if(save){
+      raster::writeRaster(x=temp_r, filename = paste0(outputPath, "/", name, "_", i),
+                          format = format, datatype = dataType, overwrite = TRUE, ...)  
     }
     
-    unlink(paste0(outputPath, "/temp_", name, "_", i), recursive = TRUE)
+    unlink(x=paste0(outputPath, "/temp_", name, "_", i), recursive = TRUE)
     
     setTxtProgressBar(pb, i)
   }
@@ -175,10 +175,10 @@ split_replace <- function(raster, partPerSide, h, v, outputPath, name, save = TR
 getAggregate <- function(raster, h = 1, v = 1){
   
   if( nlayers(raster) > 1 ){
-    raster <- raster::subset(raster,1)
+    raster <- raster::subset(x=raster, subset=1)
   }
   
-  agg <- aggregate(raster, fact = c(h,v))
+  agg <- aggregate(x = raster, fact = c(h,v))
   
   agg
 }
